==> myfaces-core-assembly-1.1.10-src.zip: org/apache/myfaces/util/EnumerationIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.util;

import java.util.Enumeration;
import java.util.Iterator;

/**
 * @author Manfred Geiler (latest modification by $Author: grantsmith $)
 * @version $Revision: 472618 $ $Date: 2006-11-08 15:06:54 -0500 (Wed, 08 Nov 2006) $
 */
public class EnumerationIterator
        implements Iterator
{
    //private static final Log log = LogFactory.getLog(EnumerationIterator.class);

    private Enumeration _enumeration;

    public EnumerationIterator(Enumeration enumeration)
    {
        _enumeration = enumeration;
    }

    public boolean hasNext()
    {
        return _enumeration.hasMoreElements();
    }

    public Object next()
    {
        return _enumeration.nextElement();
    }

    public void remove()
    {
        throw new UnsupportedOperationException(this.getClass().getName() + " UnsupportedOperationException");
    }
}

==> myfaces-core-assembly-1.2.12-src.zip: org/apache/myfaces/util/EnumerationIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.util;

import java.util.Enumeration;
import java.util.Iterator;

/**
 * @author Manfred Geiler (latest modification by $Author: bommel $)
 * @version $Revision: 693059 $ $Date: 2008-09-08 06:42:28 -0500 (Mon, 08 Sep 2008) $
 */
public final class EnumerationIterator
        implements Iterator
{
    //private static final Log log = LogFactory.getLog(EnumerationIterator.class);

    private final Enumeration _enumeration;

    public EnumerationIterator(final Enumeration enumeration)
    {
        _enumeration = enumeration;
    }

    public boolean hasNext()
    {
        return _enumeration.hasMoreElements();
    }

    public Object next()
    {
        return _enumeration.nextElement();
    }

    public void remove()
    {
        throw new UnsupportedOperationException(this.getClass().getName() + " UnsupportedOperationException");
    }
}
